// ESFrameObserverSwarm.java


import java.util.*;

import jas.engine.*;
import jas.events.*;
import jas.plot.*;
import jas.io.*;

/**
 * The Observer contains the Model and the graphic widgets
 * @author Pietro Terna and his students
 * @author Michele Sonnessa: JAS porting
 */
public class ESFrameObserver extends SimModel
{

	/** update frequency */
	public int displayFrequency;

	/** the time at which we stop the simulation (if != 0) */
	public int timeToFinish;

	/** the Swarm we are observing */
	public ESFrameModel eSFrameModel;

	private TimePlot totalTimeLengthGraph;

	public void setParameters()
	{
		// fill in the relevant parameters (only two, in this case).
		displayFrequency 	= 1;
		timeToFinish			= 0;

		eSFrameModel = (ESFrameModel) Sim.engine.getModelWithID("ESFrameModel");

		eSFrameModel.parameterFrame.appendTab(this, "Observer",
								new ParametersBag(path + "ObserverParamForm.pForm.xml"));

	}

	public void simulationEnd()
	{
		System.out.println("jES virtually quitted at time " + Sim.getAbsoluteTime());
	}

	/** Create the objects used to display the model, then
	 * create the actions necessary for the simulation. This is where
	 * the schedule is built (but not run!)  Here we create a display
	 * schedule - this is used to display the state of the world and
	 * check for user input.
	 */
	public void buildModel()
	{
		buildObjects();
		buildActions();
	}

	private void buildObjects ()
	{
		totalTimeLengthGraph = new TimePlot("Ratio total time / total lengths");
		totalTimeLengthGraph.addSeries("ratio", eSFrameModel, "getTimeLengthRatio", true);
		addSimWindow(totalTimeLengthGraph);
	}


	public void buildActions ()
	{
		if (timeToFinish != 0 )
			eventList.scheduleSystem(timeToFinish, Sim.EVENT_SIMULATION_END);

		eventList.scheduleSimple(0, displayFrequency,
																totalTimeLengthGraph, Sim.EVENT_UPDATE);
	}

}
