//UnitParameters.java

import java.io.*;
import java.util.*;

import jas.engine.Sim;

/**
 * This class reads the parameters for each unit
 *
 * @author Dario Landini and Nicola Ormezzano; IO improved by Michele Sonnessa
 * @author deeply modified by Pietro Terna to deal with simple or complex
 * units
 */

public class UnitParameters
{

	/** the vector of the unit numbers */
	public int[] unitNumber;
	/** the vector of simple unit production phase (simple=with a unique
	activity) */
	public int[] simpleUnitProductionPhase;
	/** total unit number */
	public int totalUnitNumber;
	int i, ii;
	
	/** the constructor of UnitParameters
	 */
	public UnitParameters(int un)
	{
		totalUnitNumber = un;
	}
	
	/** read the unit numbers and production phasesvfrom the
	 *  unitData/unitBasicData.txt file */
	public void readUnitData()
	{
	
		// the unit numbers and production phases
		// from the unitData/unitBasicData.txt file
		try{
		    unitNumber = new int[totalUnitNumber];
		    simpleUnitProductionPhase = new int[totalUnitNumber];
		
		    // read the file
		    BufferedReader fileUnitBasicData = null;
		    StringTokenizer t;
		    fileUnitBasicData = new
			BufferedReader(new FileReader(Sim.getPathOf(this) + "unitData/unitBasicData.txt"));
		
		    // reading a control line (titles)
		    String line = " ", lineTest =
			"unit_#___prod.phase_#";
		
		    line=fileUnitBasicData.readLine();
		    if (! line.equals(lineTest))
			{
			    System.out.println(
			    "First line in unitData/unitBasicData.txt must contain:");
			    System.out.println(lineTest);
			    System.exit(1);
			}
		    line=" ";
		
		    // starting with a void line; the actual
		    // reading is done in MyReader, dealing also
		    // with the missing data case
		    t = new StringTokenizer(line, " ");
		
		    for(i = 0; i < totalUnitNumber; i++)
			{
			    t=MyReader.check(Sim.getPathOf(this) + "unitData/unitBasicData.txt",
					     fileUnitBasicData, line, t);
			    if(! t.hasMoreTokens())
				lackingData(Sim.getPathOf(this) + "unitData/unitBasicData.txt");
			    unitNumber[i]    = Integer.parseInt(t.nextToken());
			    if(! t.hasMoreTokens())
				lackingData(Sim.getPathOf(this) + "unitData/unitBasicData.txt");
			    simpleUnitProductionPhase[i]
				             = Integer.parseInt(t.nextToken());
			}
		
		    fileUnitBasicData.close();
		}
		catch (FileNotFoundException fnfe)
		    {
			System.out.println(fnfe);
			System.exit(1);
		    }
		catch (IOException e)
		    {
			System.out.println("IOException:" + e.toString());
			System.exit(1);
		    }
	}
	
	/** setting the parameters of (normal) units */
	public void setParametersTo(int i, Unit aUnit){
		String fileName;
		int unitProductionPhase, nOfPhasesToDealWith, phaseInventories, n;
		
		n=getUnitNumber(i);
		aUnit.setUnitNumber(n);
		aUnit.setProductionPhase(getSimpleUnitProductionPhase(i));
	}
	
	
	/** returning the unit number for a specific (normal) unit */
	public int getUnitNumber(int i){
		return unitNumber[i-1];
	}
	
	/** returning the production phase for a specific simple unit */
	public int getSimpleUnitProductionPhase(int i){
		return simpleUnitProductionPhase[i-1];
	}
	
	/** conclude execution if data are lacking */
	public void lackingData(String s){
		System.out.println("Lacking data in " + s);
		System.exit(1);
	}

}
